import CodeMirror from "codemirror";
import * as React from "react";
import { FC, useEffect, useRef } from "react";

export enum Mode {
  JavaScript = "javascript",
  Markdown = "markdown"
}

export interface Props {
  defaultValue?: string;
  lineNumbers?: boolean;
  onChange: (event: any) => void;
  mode: Mode;
}

export const CodeEditor: FC<Props> = ({
  defaultValue,
  mode,
  onChange,
  lineNumbers = false
}) => {
  const textAreaEl = useRef<HTMLTextAreaElement>(null);

  useEffect(() => {
    const codeMirror = CodeMirror.fromTextArea(textAreaEl.current!, {
      lineNumbers,
      mode
    });

    codeMirror.on("change", obj => {
      onChange(obj.getValue());
    });
  }, []);

  return (
    <textarea
      data-testid="textarea"
      ref={textAreaEl}
      defaultValue={defaultValue}
    />
  );
};
